@@ -2,7 +2,7 @@
  * libdicom by Tony Voet *
  *************************/
 /*
- * $Id: basic.c,v 1.26 2006/12/08 21:50:24 enlf Exp $
+ * $Id: basic.c,v 1.27 2013/06/24 23:00:45 enlf Exp $
  */
 
 #include <stdio.h>
@@ -66,6 +66,7 @@ int dicom_open(const char *file)
 {
   U16	magic=0x1234;
   char  vr[2];
+  int	r;
 #if MEDCON_INTEGRATED
   char  buffer[512];
 #else
@@ -122,9 +123,10 @@ int dicom_open(const char *file)
   }
 #endif
 
-  fread(buffer,1,132,stream);
-  if (dicom_check(0))
-    return -5;
+  r = fread(buffer,1,132,stream);
+  if (r != 132) {
+    if (dicom_check(0)) return -5;
+  }
 
   if (!strncmp(buffer+128,"DICM",4))
   {
@@ -136,10 +138,16 @@ int dicom_open(const char *file)
     syntax=LITTLE|EXPLICIT;
 
     /* watch out for LITTLE|IMPLICIT */
-    fread(&element.group,2,2,stream);
+    r = fread(&element.group,2,2,stream);
+    if (r != 2) {
+      if (dicom_check(0)) return -6;
+    }
     dicom_swap(&element.group,2);
     dicom_swap(&element.element,2);
-    fread(vr,1,2,stream);
+    r = fread(vr,1,2,stream);
+    if (r != 2) {
+      if (dicom_check(0)) return -7;
+    }
     element.vr=(*vr<<8)|vr[1];
 
     if (element.vr != UL) syntax=LITTLE|IMPLICIT;  /* weird */
@@ -190,6 +198,7 @@ ELEMENT *dicom_element(void)
   long	rewind;
   U16	tmp;
   char	vr[2];
+  int	r;
 
   dicom_log(DEBUG,"dicom_element()");
 
@@ -198,9 +207,10 @@ ELEMENT *dicom_element(void)
 
   position=ftell(stream);
 
-  fread(&element.group,2,2,stream);
-  if (dicom_check(-1))
-    return 0L;
+  r = fread(&element.group,2,2,stream);
+  if (r != 2) {
+    if (dicom_check(-1)) return 0L;
+  }
   dicom_swap(&element.group,2);
   dicom_swap(&element.element,2);
 
@@ -236,12 +246,18 @@ ELEMENT *dicom_element(void)
   {
     dicom_vr();
 
-    fread(&element.length,4,1,stream);
+    r = fread(&element.length,4,1,stream);
+    if (r != 1) {
+      if (dicom_check(-1)) return 0L;
+    }
     dicom_swap(&element.length,4);
   }
   else
   {
-    fread(vr,1,2,stream);
+    r = fread(vr,1,2,stream);
+    if (r != 2) {
+      if (dicom_check(-1)) return 0L;
+    }
     element.vr=(*vr<<8)|vr[1];
 
     switch(element.vr)
@@ -253,12 +269,18 @@ ELEMENT *dicom_element(void)
     case UT :
       fseek(stream,2,SEEK_CUR);
 
-      fread(&element.length,4,1,stream);
+      r = fread(&element.length,4,1,stream);
+      if (r != 1) {
+        if (dicom_check(-1)) return 0L;
+      }
       dicom_swap(&element.length,4);
       break;
 
     default :
-      fread(&tmp,2,1,stream);
+      r = fread(&tmp,2,1,stream);
+      if (r != 1) {
+        if (dicom_check(-1)) return 0L;
+      }
       dicom_swap(&tmp,2);
       element.length=tmp;
     }
@@ -364,6 +386,7 @@ U32 mdc_dicom_ftell(void)
 
 int dicom_load(VR vr)
 {
+  int r;
   dicom_log(DEBUG,"dicom_load()");
 
   if (!stream)
@@ -397,11 +420,10 @@ int dicom_load(VR vr)
       return -2;
     }
     memset(element.value.UN,0,element.length + 4);
-    fread(element.value.UN,1,element.length,stream);
-    if (dicom_check(0))
-    {
+    r = fread(element.value.UN,1,element.length,stream);
+    if (r != element.length) {
       eNlfSafeFree(element.value.UN);
-      return -3;
+      if (dicom_check(0)) return -3;
     }
 
     mdc_dicom_endian();
@@ -462,6 +484,7 @@ void mdc_dicom_switch_syntax_endian(void)
    routine and get the header info we need */
 int mdc_dicom_load(VR vr)
 {
+  int	r;
   dicom_log(DEBUG,"dicom_load()");
 
   if (!stream)
@@ -493,11 +516,10 @@ int mdc_dicom_load(VR vr)
       return -2;
     }
     memset(element.value.UN,0,element.length + 4);
-    fread(element.value.UN,1,element.length,stream);
-    if (dicom_check(0))
-    {
+    r = fread(element.value.UN,1,element.length,stream);
+    if (r != element.length) {
       eNlfSafeFree(element.value.UN);
-      return -3;
+      if (dicom_check(0)) return -3;
     }
 
     mdc_dicom_endian();
