@@ -7,7 +7,7 @@
  * from the Cornell lossless JPEG code
  */
 /*
- * $Id: decomp.c,v 1.5 2004/08/18 21:38:43 enlf Exp $
+ * $Id: decomp.c,v 1.6 2013/06/25 21:32:20 enlf Exp $
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -47,8 +47,10 @@ static void efree(void **ptr)
 int ReadJpegData (Uchar *buffer, int numBytes)
 {
     unsigned long size = sizeof(unsigned char);
+    int r;
 
-    fread(buffer,size,(unsigned)numBytes,JpegInFile);
+    r = fread(buffer,size,(unsigned)numBytes,JpegInFile);
+    if (r != numBytes) return r;
 
     return numBytes;  
 }
