@@ -6,7 +6,7 @@
  *
  */
 /*
- * $Id: mcu.h,v 1.1 2002/10/14 21:56:02 enlf Exp $
+ * $Id: mcu.h,v 1.2 2004/12/14 22:59:34 enlf Exp $
  */
 #ifndef _MCU
 #define _MCU
@@ -14,7 +14,7 @@
 /*
  * An MCU (minimum coding unit) is an array of samples.
  */
-typedef short ComponentType; /* the type of image components */
+typedef unsigned short ComponentType; /* the type of image components */
 typedef ComponentType *MCU;  /* MCU - array of samples */
 
 extern MCU *mcuTable; /* the global mcu table that buffers the source image */
