@@ -10,11 +10,11 @@
  * Author       : Andy Loening                                             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-conc.h,v 1.27 2008/03/06 11:38:34 enlf Exp $
+/* $Id: m-conc.h,v 1.35 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2008 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -53,7 +53,7 @@ typedef enum {
   MDC_CONC_NUM_MODALITIES = 4
 } MdcConcModalityTypes;
 
-/* concorde data file types (integer) */
+/* siemens/concorde data file types (integer) */
 typedef enum {
   MDC_CONC_FILE_UNKNOWN,
   MDC_CONC_FILE_LIST_MODE,
@@ -71,10 +71,12 @@ typedef enum {
   MDC_CONC_FILE_AXIAL_GEOMETRIC_CORRECTION,
   MDC_CONC_FILE_CT_PROJECTION_DATA,
   MDC_CONC_FILE_SPECT_RAW_PROJECTION_DATA,
+  MDC_CONC_FILE_SPECT_ENERGY_PROJECTION_DATA,
+  MDC_CONC_FILE_SPECT_NORMALIZATION_DATA,
   MDC_CONC_NUM_FILE_TYPES
 } MdcConcFileTypes;
 
-/* concorde acquisition modes (integer) */
+/* siemens/concorde acquisition modes (integer) */
 typedef enum {
   MDC_CONC_ACQ_UNKNOWN,                    /* Unknown acquisition mode */
   MDC_CONC_ACQ_BLANK,                      /* Blank acquisition */
@@ -90,6 +92,9 @@ typedef enum {
   MDC_CONC_ACQ_SPECT_PLANAR_PROJECTION,    /* SPECT planar projection acquisition */
   MDC_CONC_ACQ_SPECT_MULTIPROJECTION,      /* SPECT multi-projection acquisition */
   MDC_CONC_ACQ_SPECT_CALIBRATION,          /* SPECT calibration acquisition */
+  MDC_CONC_ACQ_SPECT_NORMALIZATION,        /* SPECT normalization acquisition */
+  MDC_CONC_ACQ_SPECT_DETECTOR_SETUP,       /* SPECT detector setup acquisition */
+  MDC_CONC_ACQ_SPECT_SCOUT_VIEW,            /* SPECT scout view acquisition */
   MDC_CONC_NUM_ACQ_MODES
 } MdcConcAcqModes;
 
@@ -137,10 +142,12 @@ typedef enum {
   MDC_CONC_RECON_UNKNOWN,     /* Unknown, or no, algorithm type */
   MDC_CONC_RECON_FBP,         /* Filtered Backprojection */
   MDC_CONC_RECON_OSEM2D,      /* OSEM2D */
-  MDC_CONC_RECON_UNUSED3,     /* unused */
+  MDC_CONC_RECON_OSEM3D,      /* OSEM3D */
   MDC_CONC_RECON_UNUSED4,     /* unused */
   MDC_CONC_RECON_UNUSED5,     /* unused */
-  MDC_CONC_RECON_OSEM3D_MAP,  /* OSEM3D followed by MAP */
+  MDC_CONC_RECON_OSEM3D_MAP,  /* OSEM3D followed by MAP or FastMAP */
+  MDC_CONC_RECON_MAPTR,       /* MAPTR for transmission image */
+  MDC_CONC_RECON_FELDKAMP,    /* Feldkamp cone beam */
   MDC_CONC_NUM_RECON_TYPES
 } MdcConcReconTypes;
 
@@ -153,9 +160,11 @@ typedef enum {
 
 /* deadtime correction applied to the data set */
 typedef enum {
-  MDC_CONC_DEAD_CORR_NONE,       /* No deadtime correction applied */
-  MDC_CONC_DEAD_CORR_GLOBAL,     /* Global estimate based on singles */
-  MDC_CONC_DEAD_CORR_CMS,        /* CMS estimate based on singles */
+  MDC_CONC_DEAD_CORR_NONE,           /* No deadtime correction applied */
+  MDC_CONC_DEAD_CORR_GLOBAL,         /* Global estimate based on singles */
+  MDC_CONC_DEAD_CORR_CMS,            /* CMS estimate based on singles */
+  MDC_CONC_DEAD_CORR_GLOBAL_RUNNING, /* Global estimate based on running average */
+  MDC_CONC_DEAD_CORR_BLOCK,          /* Blank/TX singles estimate (block based) */ 
   MDC_CONC_NUM_DEAD_CORR_TYPES
 } MdcConcDeadCorrTypes;
 
@@ -172,20 +181,24 @@ typedef enum {
 } MdcConcAttnCorrTypes;
 
 typedef enum {
-  MDC_CONC_SCATTER_CORR_NONE,                     /* No scatter correction applied */
-  MDC_CONC_SCATTER_CORR_TAILS,                    /* Fit of emission tail */
-  MDC_CONC_SCATTER_CORR_MONTE_CARLO,              /* Monte Carlo of emission and transmission data */
-  MDC_CONC_SCATTER_CORR_DIRECT,                   /* Direct calculation from analytical formulas */
+  MDC_CONC_SCATTER_CORR_NONE,            /* No scatter correction applied */
+  MDC_CONC_SCATTER_CORR_TAILS,           /* Fit of emission tail */
+  MDC_CONC_SCATTER_CORR_MONTE_CARLO,     /* Monte Carlo of emission and transmission data */
+  MDC_CONC_SCATTER_CORR_DIRECT,          /* Direct calculation from analytical formulas */
+  MDC_CONC_SCATTER_CORR_MODEL,           /* Model-based scatter for singles TX */
+  MDC_CONC_SCATTER_CORR_OFF_WINDOW,      /* TX off-window windowed coincidence subtraction */
+  MDC_CONC_SCATTER_CORR_SCALED,          /* Singles TX scaled scatter from attenuation subtraction */
   MDC_CONC_NUM_SCATTER_CORR_TYPES
 } MdcConcScatterCorrTypes;
 
 
 typedef enum {
-  MDC_CONC_EVENT_UNKNOWN,        /* Unknown event type */
-  MDC_CONC_EVENT_SINGLES,        /* Singles */
-  MDC_CONC_EVENT_COINCIDENCES,   /* Prompt events (coincidences) */
-  MDC_CONC_EVENT_DELAYS,         /* Delay events */
-  MDC_CONC_EVENT_TRUES,          /* Trues */
+  MDC_CONC_EVENT_UNKNOWN,         /* Unknown event type */
+  MDC_CONC_EVENT_SINGLES,         /* Singles */
+  MDC_CONC_EVENT_COINCIDENCES,    /* Prompt events (coincidences) */
+  MDC_CONC_EVENT_DELAYS,          /* Delay events */
+  MDC_CONC_EVENT_TRUES,           /* Trues */
+  MDC_CONC_EVENT_ENERGY_SPECTRUM, /* Energy spectrum data */
   MDC_CONC_NUM_EVENT_TYPES
 } MdcConcEventTypes;
 
@@ -330,7 +343,9 @@ typedef enum {
    12 - Transaxial geometric correction
    13 - Axial geometric correction
    14 - CT projection data
-   15 - SPECT raw projection data */
+   15 - SPECT raw projection data 
+   16 - SPECT energy data from projections
+   17 - SPECT normalization data */
   MDC_CONC_HDR_FILE_TYPE,
 
   /* Acquisition mode (integer)
@@ -376,6 +391,9 @@ typedef enum {
   /* Number of frames in data file (integer) */
   MDC_CONC_HDR_TOTAL_FRAMES,
 
+  /* Number of time frames in data file (integer) */
+  MDC_CONC_HDR_TIME_FRAMES,
+
   /* Isotope description (string) */
   MDC_CONC_HDR_ISOTOPE,
 
@@ -559,10 +577,13 @@ typedef enum {
   /*   0 - Unknown, or no, algorithm type */
   /*   1 - Filtered Backprojection */
   /*   2 - OSEM2D */
-  /*   3 - unused */
+  /*   3 - OSEM3D */
   /*   4 - unused */
   /*   5 - unused */
-  /*   6 - OSEM3D followed by MAP */
+  /*   6 - OSEM3D followed by MAP or FastMAP */
+  /*   7 - MAPTR for transmission image */
+  /*   8 - MAP 3D reconstruction */
+  /*   9 - Feldkamp cone beam */
   MDC_CONC_HDR_RECON_ALGORITHM,
 
   /* Version of reconstruction program used (float) */
@@ -622,6 +643,8 @@ typedef enum {
   /*   0 - No deadtime correction applied */
   /*   1 - Global estimate based on singles */
   /*   2 - CMS estimate based on singles */
+  /*   3 - Global estimate based on running deadtime average */
+  /*   4 - Blank/TX singles estimate (block based) */
   MDC_CONC_HDR_DEADTIME_CORRECTION_APPLIED,
 
   /* Decay correction applied to data set (integer) */
@@ -651,13 +674,22 @@ typedef enum {
   /*   5 - Calculated by geometry */
   /*   6 - Non-positron source singles based TX */
   /*   7 - Point source in non-windowed TX coincidence */
+  /*   8 - Generated from CT image */
   MDC_CONC_HDR_ATTENUATION_APPLIED,
 
+  /* Attenuation correction filename, possibly including path (string) */
+  /*    NOTE: Filename may contain spaces, therefore the ENTIRE */
+  /*          line, up to the EOL, is used after the parameter name. */
+  MDC_CONC_HDR_ATTENUATION_FILENAME,
+
   /* Scatter correction applied to data set (integer) */
   /*   0 - No scatter correction applied */
   /*   1 - Fit of emission tail */
   /*   2 - Monte Carlo of emission and transmission data */
   /*   3 - Direct calculation from analytical formulas */
+  /*   4 - Model-based scatter for singles TX */
+  /*   5 - TX off-window windowed coincidence subtraction */
+  /*   6 - Singles TX scaled scatter from attenuation subtraction */
   MDC_CONC_HDR_SCATTER_CORRECTION,
 
   /* Version of scatter program used (float) */
@@ -916,8 +948,9 @@ typedef enum {
 
 
   /* Gantry rotation (integer) 
-     0 (FALSE) - Gantry does NOT rotate
-     !0 (TRUE) - Gantry does rotate */
+     0 - No gantry rotation
+     1 - Rotation with discrete steps
+     2 - Continuous rotation */
   MDC_CONC_HDR_GANTRY_ROTATION,
 
   /* Rotation direction (integer) 
@@ -934,6 +967,8 @@ typedef enum {
   /* Number of rotation projections for rotating gantry (integer) */
   MDC_CONC_HDR_NUMBER_OF_PROJECTIONS,
 
+  /* Number of gantry revolutions for rotating gantry (float) */
+  MDC_CONC_HDR_GANTRY_ROTATIONS,
 
   /* Following parameters are used for CT modality only */
 
@@ -1111,14 +1146,21 @@ typedef enum {
   /* Frame number (integer) */
   MDC_CONC_BLOCK_FRAME,
 
+  /* Detector panel - NOTE: "ring" systems are "0" ONLY (integer) */
+  MDC_CONC_BLOCK_DETECTOR_PANEL,
+
   /* Event type (integer) */
   /*   0 - Unknown event type */
   /*   1 - Singles */
   /*   2 - Prompt events (coincidences) */
   /*   3 - Delay events */
   /*   4 - Trues (prompts - delays) */
+  /*   5 - Energy spectrum data */
   MDC_CONC_BLOCK_EVENT_TYPE,
 
+  /* Energy window - NOTE PET/CT systems are typically "0" only (integer) */
+  MDC_CONC_BLOCK_ENERGY_WINDOW,
+
   /* Gate number (integer) */
   MDC_CONC_BLOCK_GATE,
 
