@@ -60,11 +60,11 @@
  *                MdcAddCompressionExt()  - Add  compression extension     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-fancy.c,v 1.67 2013/06/23 21:51:19 enlf Exp $
+/* $Id: m-fancy.c,v 1.70 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -197,13 +197,13 @@ int MdcPrintValue(FILE *fp, Uint8 *pvalue, Uint16 type)
    case BIT8_S:
     {
       Int8 *val = (Int8 *) pvalue;
-      fprintf(fp,"%hd",val[0]);
+      fprintf(fp,"%hhd",val[0]);
     }
     break;
    case BIT8_U:
     {
       Uint8 *val = (Uint8 *) pvalue;
-      fprintf(fp,"%hu",val[0]);
+      fprintf(fp,"%hhu",val[0]);
     }
     break;
    case BIT16_S:
