@@ -41,11 +41,11 @@
  *                We only write GIF89a animated gifs                       *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-gif.c,v 1.42 2013/06/23 21:51:19 enlf Exp $
+/* $Id: m-gif.c,v 1.46 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -836,8 +836,11 @@ int MdcWriteGifHeader(FILEINFO *fi, MDC_GIFOPT *opt)
   gh.flags=0;
 
   /* set up the global flags */
-  if (fi->palette == NULL) gh.flags=(((bits-1) & 0x07)<<4);
-  else gh.flags = (0x80 | ((bits-1)<<4) | ((bits-1) & 0x07));
+  if (fi->map < MDC_MAP_PRESENT) {
+    gh.flags=(((bits-1) & 0x07)<<4);
+  }else{
+    gh.flags = (0x80 | ((bits-1)<<4) | ((bits-1) & 0x07));
+  } 
 
   MdcSWAP(gh.screenwidth); MdcSWAP(gh.screenheight);
  
@@ -845,7 +848,7 @@ int MdcWriteGifHeader(FILEINFO *fi, MDC_GIFOPT *opt)
   fwrite((char *)&gh,1,MDC_GIF_GH_SIZE,fi->ofp);
 
   /* write the colour map */
-  if (fi->palette != NULL) fwrite(fi->palette,1U,3U*(1U<<bits),fi->ofp);
+  fwrite(fi->palette,1U,3U*(1U<<bits),fi->ofp);
 
   return(ferror(fi->ofp));
 }
