@@ -24,11 +24,11 @@
  *   Yaorong                                                               *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-matrix.c,v 1.35 2013/06/23 21:51:19 enlf Exp $
+/* $Id: m-matrix.c,v 1.38 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -948,7 +948,7 @@ Int32 mdc_mat_enter( fptr, matnum, nblks)
   FILE *fptr; Int32 matnum, nblks;
 {
 
-	Int32 dirblk, dirbufr[128], i, nxtblk, busy, oldsize;
+	Int32 dirblk, dirbufr[128+4], i, nxtblk, busy, oldsize;
 
 	dirblk = MdcMatFirstDirBlk;
 	mdc_mat_rblk( fptr, dirblk, (Uint8 *)dirbufr, 1);
@@ -1013,6 +1013,7 @@ Int32 mdc_mat_enter( fptr, matnum, nblks)
 	  for (i=4; i<128; i++) dirbufr[i] = 0;
 	 }
 	}
+
 	dirbufr[i] = matnum;
 	dirbufr[i+1] = nxtblk;
 	dirbufr[i+2] = nxtblk + nblks;
