@@ -28,11 +28,11 @@
  * specific, prior written permission of Sam Leffler and Silicon Graphics. *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-qmedian.c,v 1.22 2013/06/23 21:51:19 enlf Exp $
+/* $Id: m-qmedian.c,v 1.25 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -860,7 +860,7 @@ static char *quant_fsdither(Uint8 *srcRGB, Uint8 *dest8)
   if (thisline == NULL) return("Unable to malloc thisline");
   nextline = (short *)malloc(imagewidth * 3 * sizeof (short));
   if (nextline == NULL) {
-    MdcFree(nextline);
+    MdcFree(thisline);
     return("Unable to malloc nextline");
   }
 
