@@ -17,11 +17,11 @@
  *                MdcSplitFrames()        - Write each frame to a file     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-split.c,v 1.32 2013/06/23 21:51:19 enlf Exp $
+/* $Id: m-split.c,v 1.35 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -244,7 +244,10 @@ char *MdcSplitSlices(FILEINFO *fi, int format, int prefixnr)
   if (ofi == NULL) return("Couldn't malloc output struct");
 
   tpath = (char *)malloc(MDC_MAX_PATH);
-  if (tpath == NULL) return("Couldn't malloc tpath");
+  if (tpath == NULL) {
+    MdcFree(ofi);
+    return("Couldn't malloc tpath");
+  }
   if (XMDC_GUI == MDC_NO) {
     MdcGetSafeString(tpath,fi->ifname,strlen(fi->ifname),MDC_MAX_PATH);
   }else{
@@ -318,7 +321,10 @@ char *MdcSplitFrames(FILEINFO *fi, int format, int prefixnr)
   if (ofi == NULL) return("Couldn't malloc output struct");
 
   tpath = (char *)malloc(MDC_MAX_PATH);
-  if (tpath == NULL) return("Couldn't malloc tpath");
+  if (tpath == NULL) {
+    MdcFree(ofi);
+    return("Couldn't malloc tpath");
+  }
   if (XMDC_GUI == MDC_NO) {
     MdcGetSafeString(tpath,fi->ifname,strlen(fi->ifname),MDC_MAX_PATH);
   }else{
