@@ -21,11 +21,11 @@
  *                MdcContrastRemap()         - Apply contrast remapping    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-transf.c,v 1.40 2013/06/23 21:51:20 enlf Exp $
+/* $Id: m-transf.c,v 1.43 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -265,7 +265,7 @@ char *MdcMakeSquare(FILEINFO *fi, int SQR_TYPE)
 char *MdcCropImages(FILEINFO *fi, MDC_CROP_INFO *ecrop)
 {
   MDC_CROP_INFO icrop, *crop;
-  FILEINFO *new, *cur=fi;
+  FILEINFO fi_tmp, *new=&fi_tmp, *cur=fi;
   IMG_DATA *newid, *curid;
   Uint8 *curbuf, *newbuf;
   Uint32 i, r, pixelbytes, curlinebytes, newlinebytes, newimgbytes;
@@ -301,9 +301,7 @@ char *MdcCropImages(FILEINFO *fi, MDC_CROP_INFO *ecrop)
   if ((crop->yoffset + crop->height) > cur->mheight)
     crop->height = cur->mheight - crop->yoffset;
 
-  /* get temporary FILEINFO structure */
-  new = (FILEINFO *)malloc(sizeof(FILEINFO));
-  if (new == NULL) return("Crop - Bad malloc FILEINFO struct");
+  /* copy cur -> new */
   MdcCopyFI(new,cur,MDC_NO,MDC_YES);
 
   /* set global parameters */
@@ -312,7 +310,7 @@ char *MdcCropImages(FILEINFO *fi, MDC_CROP_INFO *ecrop)
   new->mheight= crop->height;  new->dim[2] = crop->height;
 
   if (!MdcGetStructID(new,new->number)) {
-    MdcCleanUpFI(new); MdcFree(new);
+    MdcCleanUpFI(new);
     return("Crop - Bad malloc IMG_DATA structs");
   }
 
@@ -349,7 +347,7 @@ char *MdcCropImages(FILEINFO *fi, MDC_CROP_INFO *ecrop)
      /* realloc cropped buffer */
      newid->buf = (Uint8 *)realloc(newid->buf,newimgbytes);
      if (newid->buf == NULL) {
-       MdcCleanUpFI(new); MdcFree(new);
+       MdcCleanUpFI(new);
        return("Crop - Bad realloc cropped buffer");
      }
 
@@ -357,7 +355,8 @@ char *MdcCropImages(FILEINFO *fi, MDC_CROP_INFO *ecrop)
 
   /* check integrity */
   if ((msg = MdcImagesPixelFiddle(new)) != NULL) {
-    MdcCleanUpFI(new); MdcFree(new); return(msg);
+    MdcCleanUpFI(new);
+    return(msg);
   }
 
   /* remove cur */
@@ -366,7 +365,7 @@ char *MdcCropImages(FILEINFO *fi, MDC_CROP_INFO *ecrop)
   /* copy new -> cur */
   MdcCopyFI(cur,new,MDC_NO,MDC_YES);
 
-  /* just rehang image pointer */
+  /* just rehook image pointer */
   cur->number = new->number;
   cur->image  = new->image;
 
@@ -374,8 +373,8 @@ char *MdcCropImages(FILEINFO *fi, MDC_CROP_INFO *ecrop)
   new->number = 0;
   new->image  = NULL;
 
-  /* now safely remove new */
-  MdcCleanUpFI(new); MdcFree(new);
+  /* now safely cleanup new */
+  MdcCleanUpFI(new);
 
   return(NULL); 
 
