@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xcolmap.h,v 1.19 2013/06/23 21:51:20 enlf Exp $
+/* $Id: xcolmap.h,v 1.22 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -28,7 +28,7 @@
    with this program; if not, write to the Free Software Foundation, Inc.,
    59 Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ifndef __XCOPMAP_H__
+#ifndef __XCOLMAP_H__
 #define __XCOLMAP_H__
 
 /****************************************************************************
