@@ -26,11 +26,11 @@
  *                XMdcRawPredefSelOpen()            - Raw Predef Load      * 
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xfilesel.c,v 1.39 2013/06/23 21:51:20 enlf Exp $
+/* $Id: xfilesel.c,v 1.42 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -460,7 +460,7 @@ void XMdcFileSelSave(GtkWidget *widget, guint format)
 
    GtkWidget *menu=NULL;
    GtkWidget *active=NULL;
-   guint nr=mitem_nr[format];
+   guint nr;
 
    nr = (format < MDC_MAX_FRMTS) ? mitem_nr[format] : 1;
 
