@@ -11,11 +11,11 @@
  *                XMdcShowFileInfo()        - Display general file info    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xinfo.c,v 1.68 2013/06/23 21:51:20 enlf Exp $
+/* $Id: xinfo.c,v 1.71 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -425,7 +425,7 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   sprintf(xmdcstr,"bits        : %hu\n",my.fi->bits);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
   v = (int)my.fi->type;
-  sprintf(xmdcstr,"type        : %hu (= %s)\n",v,MdcGetStrPixelType(v));
+  sprintf(xmdcstr,"type        : %d (= %s)\n",v,MdcGetStrPixelType(v));
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
 
   sprintf(xmdcstr,"dim[0]      : %-5hd (= total in use)\n",my.fi->dim[0]);
@@ -532,11 +532,11 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"dose_time_second : %02d\n",my.fi->dose_time_second);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"nr_series        : %hd\n",my.fi->nr_series);
+  sprintf(xmdcstr,"nr_series        : %d\n",my.fi->nr_series);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"nr_acquisition   : %hd\n",my.fi->nr_acquisition);
+  sprintf(xmdcstr,"nr_acquisition   : %d\n",my.fi->nr_acquisition);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"nr_instance      : %hd\n",my.fi->nr_instance);
+  sprintf(xmdcstr,"nr_instance      : %d\n",my.fi->nr_instance);
   gtk_text_insert(GTK_TEXT(text),fixed,NULL,NULL,xmdcstr,-1);
   v = (int)my.fi->decay_corrected;
   sprintf(xmdcstr,"decay_corrected  : %d (= %s)\n",v,MdcGetStrYesNo(v));
