@@ -18,11 +18,11 @@
  *                XMdcLabelSel()                - Label selection          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xlabels.c,v 1.28 2013/06/23 21:51:20 enlf Exp $
+/* $Id: xlabels.c,v 1.31 2015/12/22 13:59:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2013 by Erik Nolf
+   Copyright (C) 1997-2016 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -132,7 +132,7 @@ char *XMdcGetImageLabelTimes(Uint32 nr)
   f = id->frame_number;
   duration = MdcSingleImageDuration(my.fi,f-1);
   strncpy(s,MdcGetStrHHMMSS(id->slice_start),10); s[9]='\0';
-  strncpy(d,MdcGetStrHHMMSS(duration),10);        s[9]='\0';
+  strncpy(d,MdcGetStrHHMMSS(duration),10);        d[9]='\0';
 
   sprintf(labeltimes,"%u S=%s D=%s",f,s,d);
 
